@@ -63,10 +63,4 @@ language languages[51] = {
 	{ "yi", "Yiddish" }
 };
 
-GtkWidget* flags [51];
-GtkWidget* flags2[51];
-static GdkPixbuf* pflags[51];
-gint src_lang_num = 10;
-gint tra_lang_num = 13;
-
 #endif /* __LANG_H__ */
